@@ -1,6 +1,7 @@
 #! -*- encoding: utf-8 -*-
 import os
 import sys
+import logging
 
 import click
 from autoupgrade import Package
@@ -28,6 +29,8 @@ from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.tokens import Tokens
 
+from suite_py.lib import logger
+
 
 @click.group()
 @click.option(
@@ -41,8 +44,9 @@ from suite_py.lib.tokens import Tokens
     type=click.INT,
     help="Timeout in seconds for Captainhook operations",
 )
+@click.option("-v", "--verbose", count=True)
 @click.pass_context
-def main(ctx, project, timeout):
+def main(ctx, project, timeout, verbose):
     Package("suite_py").upgrade()
     print(f"v{__version__}")
 
@@ -61,6 +65,10 @@ def main(ctx, project, timeout):
     ):
         sys.exit()
 
+    if verbose:
+        logger.setLevel(logging.DEBUG)
+        logger.debug("Logging as 'DEBUG'")
+
     ctx.ensure_object(dict)
     ctx.obj["project"] = os.path.basename(project)
     if timeout:
